cf\_units
=========

|Travis|_ |Coveralls|_

\(C) British Crown Copyright 2015 - 2016, Met Office

Introduction
------------
Units of measure as required by the Climate and Forecast (CF) metadata
conventions.

Provision of a wrapper class to support Unidata/UCAR UDUNITS-2, and the
netcdftime calendar functionality.


Code
----
cf_units is licenced under the GNU Lesser General Public License (LGPLv3).
The full text of the licence can be found in the COPYING and COPYING.LESSER
files.

See also
--------

* Development occurs at https://github.com/SciTools/cf_units.
* Documentation for cf_units can be found at http://scitools.org.uk/cf_units/index.html.
* The library wrapped by cf_units: `UDUNITS-2 <http://www.unidata.ucar.edu/software/udunits/udunits-2/udunits2.html>`_.

.. |Travis| image:: https://travis-ci.org/SciTools/cf_units.svg?branch=master
.. _Travis: https://travis-ci.org/SciTools/cf_units

.. |Coveralls| image:: https://coveralls.io/repos/github/SciTools/cf_units/badge.svg?branch=master
.. _Coveralls: https://coveralls.io/github/SciTools/cf_units?branch=master
